Op

Enum Op 

pub enum Op {
Show 25 variants ScanNodes { labels: Vec<String>, schema: Vec<ColDef>, must_labels: Vec<String>, forbidden_labels: Vec<String>, est_rows: i64, selectivity: f64, graph_ref: Option<String>, }, ScanRels { types: Vec<String>, schema: Vec<ColDef>, src_labels: Vec<String>, dst_labels: Vec<String>, est_rows: i64, selectivity: f64, }, Expand { input: u32, src_col: u32, types: Vec<String>, dir: ExpandDir, schema: Vec<ColDef>, src_var: String, rel_var: String, dst_var: String, legal_src_labels: Vec<String>, legal_dst_labels: Vec<String>, est_degree: f64, graph_ref: Option<String>, }, OptionalExpand { input: u32, src_col: u32, types: Vec<String>, dir: ExpandDir, schema: Vec<ColDef>, src_var: String, rel_var: String, dst_var: String, legal_src_labels: Vec<String>, legal_dst_labels: Vec<String>, graph_ref: Option<String>, }, SemiExpand { input: u32, src_col: u32, types: Vec<String>, dir: ExpandDir, schema: Vec<ColDef>, legal_src_labels: Vec<String>, legal_dst_labels: Vec<String>, }, ExpandVarLen { input: u32, src_col: u32, types: Vec<String>, dir: ExpandDir, min_hops: i32, max_hops: i32, schema: Vec<ColDef>, src_var: String, path_var: String, dst_var: String, graph_ref: Option<String>, }, Filter { input: u32, predicate: Expr, }, BlockMarker { input: u32, block_id: i32, branch_id: i32, }, Project { input: u32, exprs: Vec<Expr>, schema: Vec<ColDef>, }, Aggregate { input: u32, keys: Vec<u32>, aggs: Vec<Expr>, schema: Vec<ColDef>, }, Sort { input: u32, keys: Vec<u32>, dirs: Vec<SortDir>, }, Limit { input: u32, count: i64, skip: i64, cursor: Option<Vec<u8>>, emit_cursor: bool, }, Unwind { input: u32, list_expr: Expr, out_var: String, schema: Vec<ColDef>, }, PathConstruct { input: u32, rel_cols: Vec<u32>, schema: Vec<ColDef>, }, Union { lhs: u32, rhs: u32, all: bool, schema: Vec<ColDef>, }, CreateNode { input: u32, labels: Vec<String>, props: Expr, schema: Vec<ColDef>, out_var: String, }, CreateRel { input: u32, src_col: i32, dst_col: i32, rel_type: String, props: Expr, schema: Vec<ColDef>, out_var: String, }, Merge { input: u32, pattern: Expr, on_create_props: Expr, on_match_props: Expr, schema: Vec<ColDef>, }, Delete { input: u32, target_col: i32, detach: bool, schema: Vec<ColDef>, }, SetProperty { input: u32, target_col: i32, key: String, value_expr: Expr, schema: Vec<ColDef>, }, RemoveProperty { input: u32, target_col: i32, key: String, schema: Vec<ColDef>, }, VectorScan { input: u32, collection: String, query_vector: Expr, metric: VectorMetric, top_k: u32, approx_hint: bool, schema: Vec<ColDef>, }, Rerank { input: u32, score_expr: Expr, top_k: u32, schema: Vec<ColDef>, }, Return { input: u32, }, ConstRow,
}

Variants



ScanNodes

Fields

labels: Vec<String>
schema: Vec<ColDef>
must_labels: Vec<String>
forbidden_labels: Vec<String>
est_rows: i64
selectivity: f64
graph_ref: Option<String>


ScanRels

Fields

types: Vec<String>
schema: Vec<ColDef>
src_labels: Vec<String>
dst_labels: Vec<String>
est_rows: i64
selectivity: f64


Expand

Fields

input: u32
src_col: u32
types: Vec<String>
schema: Vec<ColDef>
src_var: String
rel_var: String
dst_var: String
legal_src_labels: Vec<String>
legal_dst_labels: Vec<String>
est_degree: f64
graph_ref: Option<String>


OptionalExpand

Fields

input: u32
src_col: u32
types: Vec<String>
schema: Vec<ColDef>
src_var: String
rel_var: String
dst_var: String
legal_src_labels: Vec<String>
legal_dst_labels: Vec<String>
graph_ref: Option<String>


SemiExpand

Fields

input: u32
src_col: u32
types: Vec<String>
schema: Vec<ColDef>
legal_src_labels: Vec<String>
legal_dst_labels: Vec<String>


ExpandVarLen

Fields

input: u32
src_col: u32
types: Vec<String>
min_hops: i32
max_hops: i32
schema: Vec<ColDef>
src_var: String
path_var: String
dst_var: String
graph_ref: Option<String>


Filter

Fields

input: u32
predicate: Expr


BlockMarker

Fields

input: u32
block_id: i32
branch_id: i32


Project

Fields

input: u32
exprs: Vec<Expr>
schema: Vec<ColDef>


Aggregate

Fields

input: u32
keys: Vec<u32>
aggs: Vec<Expr>
schema: Vec<ColDef>


Sort

Fields

input: u32
keys: Vec<u32>
dirs: Vec<SortDir>


Limit

Fields

input: u32
count: i64
skip: i64
cursor: Option<Vec<u8>>

Opaque engine-internal cursor bytes from a prior execution. When Some, the engine resumes from this cursor instead of using skip.

emit_cursor: bool

When true, the engine should emit a continuation cursor in the execution result if more rows exist beyond count.



Unwind

Fields

input: u32
list_expr: Expr
out_var: String
schema: Vec<ColDef>


PathConstruct

Fields

input: u32
rel_cols: Vec<u32>
schema: Vec<ColDef>


Union

Fields

lhs: u32
rhs: u32
all: bool
schema: Vec<ColDef>


CreateNode

Fields

input: u32
labels: Vec<String>
props: Expr
schema: Vec<ColDef>
out_var: String


CreateRel

Fields

input: u32
src_col: i32
dst_col: i32
rel_type: String
props: Expr
schema: Vec<ColDef>
out_var: String


Merge

Fields

input: u32
pattern: Expr
on_create_props: Expr
on_match_props: Expr
schema: Vec<ColDef>


Delete

Fields

input: u32
target_col: i32
detach: bool
schema: Vec<ColDef>


SetProperty

Fields

input: u32
target_col: i32
value_expr: Expr
schema: Vec<ColDef>


RemoveProperty

Fields

input: u32
target_col: i32
schema: Vec<ColDef>


VectorScan

Fields

input: u32
collection: String
query_vector: Expr
top_k: u32
approx_hint: bool
schema: Vec<ColDef>


Rerank

Fields

input: u32
score_expr: Expr
top_k: u32
schema: Vec<ColDef>


Return

Fields

input: u32


ConstRow

Zero-input source op that emits exactly one empty row. Used as the seed for standalone CREATE/INSERT without a preceding MATCH.