root_as_plexus_plan

Function root_as_plexus_plan 

pub fn root_as_plexus_plan(
    buf: &[u8],
) -> Result<PlexusPlan<'_>, InvalidFlatbuffer>
Verifies that a buffer of bytes contains a PlexusPlan and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_plexus_plan_unchecked.