PlanValidationError

Enum PlanValidationError 

pub enum PlanValidationError {
    InvalidRootOp {
        root_op: u32,
        num_ops: u32,
    },
    InputOutOfBounds {
        op_index: u32,
        field: &'static str,
        input: u32,
        num_ops: u32,
    },
    ForwardReference {
        op_index: u32,
        field: &'static str,
        input: u32,
    },
    EmptyPlan,
    ExprColOutOfBounds {
        op_index: u32,
        field: &'static str,
        col_idx: u32,
        input_width: u32,
    },
    ColumnIndexOutOfBounds {
        op_index: u32,
        field: &'static str,
        col_idx: u32,
        input_width: u32,
    },
    SchemaArityMismatch {
        op_index: u32,
        field: &'static str,
        expected: u32,
        actual: u32,
    },
    SortArityMismatch {
        op_index: u32,
        keys: u32,
        dirs: u32,
    },
    InvalidGraphRef {
        op_index: u32,
        field: &'static str,
        value: String,
    },
    NonPositiveValue {
        op_index: u32,
        field: &'static str,
        value: u32,
    },
    SchemaKindMismatch {
        op_index: u32,
        field: &'static str,
        col_idx: u32,
        expected_kind: ColKind,
        actual_kind: ColKind,
    },
}
Errors detected during structural validation of a deserialized plan.

Variants



InvalidRootOp

root_op index is out of bounds.

Fields

root_op: u32
num_ops: u32


InputOutOfBounds

An op at op_index references an input that is out of bounds.

Fields

op_index: u32
field: &'static str
input: u32
num_ops: u32


ForwardReference

An op at op_index references a forward (or self) input, which would create a cycle or depend on an op that hasn’t been computed yet.

Fields

op_index: u32
field: &'static str
input: u32


EmptyPlan

The plan contains no ops.



ExprColOutOfBounds

An op has a column index reference outside the available input width.

Fields

op_index: u32
field: &'static str
col_idx: u32
input_width: u32


ColumnIndexOutOfBounds

An op references a key/column index outside the available input width.

Fields

op_index: u32
field: &'static str
col_idx: u32
input_width: u32


SchemaArityMismatch

A schema-bearing op has inconsistent arity contracts.

Fields

op_index: u32
field: &'static str
expected: u32
actual: u32


SortArityMismatch

Sort key and sort direction vectors differ in length.

Fields

op_index: u32
keys: u32
dirs: u32


InvalidGraphRef

A graph_ref on a graph-touching op is malformed.

Fields

op_index: u32
field: &'static str
value: String


NonPositiveValue

A field requiring a strictly positive integer received zero.

Fields

op_index: u32
field: &'static str
value: u32


SchemaKindMismatch

A column referenced by a field has the wrong ColKind for the op.

Fields

op_index: u32
field: &'static str
col_idx: u32
expected_kind: ColKind
actual_kind: ColKind